@@ -17,6 +17,7 @@ class GatewayType(Enum):
     TAHOMA = 15
     VERISURE_ALARM_SYSTEM = 20
     KIZBOX_MINI = 21
+    HI_KUMO_ADAPTER = 22  # Hi Kumo Adapter SPX-WFG01 (constant added manually)
     KIZBOX_V2 = 24
     MYFOX_ALARM_SYSTEM = 25
     KIZBOX_MINI_VMBUS = 27
@@ -102,6 +103,7 @@ class ExecutionSubType(Enum):
     ACTION_GROUP = "ACTION_GROUP"
     ACTION_GROUP_SEQUENCE = "ACTION_GROUP_SEQUENCE"
     DAWN_TRIGGER = "DAWN_TRIGGER"
+    DUSK_TRIGGER = "DUSK_TRIGGER"
     DISCRETE_TRIGGER_USER = "DISCRETE_TRIGGER_USER"
     GENERIC_COMMAND_SCHEDULING = "GENERIC_COMMAND_SCHEDULING"
     IFT_CONDITION = "IFT_CONDITION"
@@ -324,6 +326,7 @@ class EventName(Enum):
     CAMERA_DISCOVERED = "CameraDiscoveredEvent"
     CAMERA_DISCOVER_FAILED = "CameraDiscoverFailedEvent"
     CAMERA_UPLOAD_PHOTO = "CameraUploadPhotoEvent"
+    COMMAND_EXECUTION_STATE_CHANGE = "CommandExecutionStateChangedEvent"
     CONDITION_GROUP_CREATED = "ConditionGroupCreatedEvent"
     CONDITION_GROUP_DELETED = "ConditionGroupDeletedEvent"
     CONDITION_GROUP_UPDATED = "ConditionGroupUpdatedEvent"
@@ -400,6 +403,7 @@ class UpdateBoxStatus(Enum):
     READY_TO_UPDATE_LOCALLY = "READY_TO_UPDATE_LOCALLY"
     UP_TO_DATE = "UP_TO_DATE"
     UNKNOWN = "UNKNOWN"
+    UPDATING = "UPDATING"
 
 
 class CommandMode(Enum):
